@@ -4,7 +4,7 @@
 #
 
 package Parallel::WorkUnit;
-$Parallel::WorkUnit::VERSION = '2.202160'; # TRIAL
+$Parallel::WorkUnit::VERSION = '2.232010'; # TRIAL
 use v5.8;
 
 # ABSTRACT: Provide multi-paradigm forking with ability to pass back data
@@ -746,7 +746,14 @@ sub start {
         confess("Parameter to start() is not a code (or codelike) reference");
     }
 
-    _start_child($sub);
+    my $pid = fork();
+
+    if ( !$pid ) {
+        # We are in the child process.
+        $sub->();
+        exit();
+    }
+
     return;
 }
 
@@ -763,21 +770,6 @@ sub _codelike {
     return;
 }
 
-# Start sub process
-#
-sub _start_child {
-    if ( $#_ != 0 ) { confess 'invalid call'; }
-    my ($sub) = @_;
-
-    my $pid = fork();
-
-    if ( !$pid ) {
-        # We are in the child process.
-        $sub->();
-        exit();
-    }
-}
-
 # Destructor emits warning if sub processes are running
 sub DESTROY {
     my $self = shift;
@@ -803,7 +795,7 @@ Parallel::WorkUnit - Provide multi-paradigm forking with ability to pass back da
 
 =head1 VERSION
 
-version 2.202160
+version 2.232010
 
 =head1 SYNOPSIS
 
@@ -1054,7 +1046,7 @@ many other children are running.
 
 This method is similar to C<async()>, but unlike C<async()>, no provision to
 receive return value or wait on the child is made.  This is somewhat similar
-to C<start> in Perl 6 (but differs as this starts a subprocess, not a new
+to C<start> in Raku (but differs as this starts a subprocess, not a new
 thread, and there is thus no shared data (changes to data in the child process
 will not be seen in the parent process).
 
@@ -1069,7 +1061,7 @@ Joelle Maslak <jmaslak@antelope.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020 by Joelle Maslak.
+This software is copyright (c) 2015-2023 by Joelle Maslak.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
